==> antd-mobile-0.9.14.tgz: package/lib/badge/demo/basic.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _whiteSpace=require('antd-mobile/components/white-space');var _whiteSpace2=_interopRequireDefault(_whiteSpace);var _badge=require('antd-mobile/components/badge');var _badge2=_interopRequireDefault(_badge);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}var

BasicTagExample=function(_React$Component){(0,_inherits3["default"])(BasicTagExample,_React$Component);function BasicTagExample(){(0,_classCallCheck3["default"])(this,BasicTagExample);return(0,_possibleConstructorReturn3["default"])(this,_React$Component.apply(this,arguments));}BasicTagExample.prototype.
render=function render(){
return _react2["default"].createElement(_reactNative.ScrollView,{style:{flex:1},automaticallyAdjustContentInsets:false,showsHorizontalScrollIndicator:false,showsVerticalScrollIndicator:false},
_react2["default"].createElement(_reactNative.View,{style:{padding:20}},
_react2["default"].createElement(_badge2["default"],{text:9},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}})),

_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_badge2["default"],{text:109,overflowCount:100},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}})),

_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_badge2["default"],{text:109},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}})),

_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_badge2["default"],{text:"new"},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}})),

_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_badge2["default"],{text:109,dot:true},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}})),

_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_badge2["default"],{text:33,corner:true},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}}))));


};return BasicTagExample;}(_react2["default"].Component);exports["default"]=BasicTagExample;module.exports=exports['default'];

==> antd-mobile-1.0.1.tgz: package/lib/badge/demo/basic.js <==
'use strict';Object.defineProperty(exports,"__esModule",{value:true});exports["default"]=undefined;var _whiteSpace=require('antd-mobile/components/white-space');var _whiteSpace2=_interopRequireDefault(_whiteSpace);var _badge=require('antd-mobile/components/badge');var _badge2=_interopRequireDefault(_badge);var _classCallCheck2=require('babel-runtime/helpers/classCallCheck');var _classCallCheck3=_interopRequireDefault(_classCallCheck2);var _possibleConstructorReturn2=require('babel-runtime/helpers/possibleConstructorReturn');var _possibleConstructorReturn3=_interopRequireDefault(_possibleConstructorReturn2);var _inherits2=require('babel-runtime/helpers/inherits');var _inherits3=_interopRequireDefault(_inherits2);
var _react=require('react');var _react2=_interopRequireDefault(_react);
var _reactNative=require('react-native');function _interopRequireDefault(obj){return obj&&obj.__esModule?obj:{"default":obj};}var

BasicTagExample=function(_React$Component){(0,_inherits3["default"])(BasicTagExample,_React$Component);function BasicTagExample(){(0,_classCallCheck3["default"])(this,BasicTagExample);return(0,_possibleConstructorReturn3["default"])(this,_React$Component.apply(this,arguments));}BasicTagExample.prototype.
render=function render(){
return _react2["default"].createElement(_reactNative.ScrollView,{style:{flex:1},automaticallyAdjustContentInsets:false,showsHorizontalScrollIndicator:false,showsVerticalScrollIndicator:false},
_react2["default"].createElement(_reactNative.View,{style:{padding:20}},
_react2["default"].createElement(_badge2["default"],{text:9},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}})),


_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_whiteSpace2["default"],null),

_react2["default"].createElement(_badge2["default"],{text:109,overflowCount:100},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}})),


_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_whiteSpace2["default"],null),

_react2["default"].createElement(_badge2["default"],{text:109},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}})),


_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_whiteSpace2["default"],null),

_react2["default"].createElement(_badge2["default"],{text:'new'},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}})),


_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_whiteSpace2["default"],null),

_react2["default"].createElement(_badge2["default"],{text:109,dot:true},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}})),


_react2["default"].createElement(_whiteSpace2["default"],null),
_react2["default"].createElement(_whiteSpace2["default"],null),

_react2["default"].createElement(_badge2["default"],{text:33,corner:true},
_react2["default"].createElement(_reactNative.View,{style:{width:52,height:52,backgroundColor:'rgba(255, 140, 101, 0.15)'}}))));




};return BasicTagExample;}(_react2["default"].Component);exports["default"]=BasicTagExample;module.exports=exports['default'];
